# Community detection by SDP, C++ Eigen implementation
This repository provides API for three different settings.
For the first setting (SDP1), it is a re-implementation from its original [Rcpp binding](https://github.com/cran/sbmSDP).
[Matlab implementation](https://github.com/aaamini/SBM-SDP) can also be referenced.

## Reference
* SDP1: Amini, Arash A., and Elizaveta Levina. "On semidefinite relaxations for the block model." The Annals of Statistics 46.1 (2018): 149-179.
* SDP for balanced two community: Abbe, Emmanuel, Afonso S. Bandeira, and Georgina Hall. "Exact recovery in the stochastic block model." IEEE Transactions on Information Theory 62.1 (2015): 471-487.
* SDP for balanced two community with side information: TBD.
